@@ -40,11 +40,11 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudfront
-import aws_cdk.aws_kms
-import aws_cdk.aws_s3
-import aws_cdk.aws_s3_deployment
-import constructs
+import aws_cdk.aws_cloudfront as _aws_cdk_aws_cloudfront_ceddda9d
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
+import aws_cdk.aws_s3 as _aws_cdk_aws_s3_ceddda9d
+import aws_cdk.aws_s3_deployment as _aws_cdk_aws_s3_deployment_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 @jsii.data_type(
@@ -67,16 +67,10 @@ class CidrAllowList:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                cidr_ranges: typing.Sequence[builtins.str],
-                cidr_type: builtins.str,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9be1ae061cd271ea75f6ed9932a2ad208594eb9b8cae56fd44d609778e3aa1fc)
             check_type(argname="argument cidr_ranges", value=cidr_ranges, expected_type=type_hints["cidr_ranges"])
             check_type(argname="argument cidr_type", value=cidr_type, expected_type=type_hints["cidr_type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "cidr_ranges": cidr_ranges,
             "cidr_type": cidr_type,
         }
@@ -132,8 +126,8 @@ class CloudFrontWebAclProps:
     def __init__(
         self,
         *,
-        cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[str, typing.Any]]] = None,
-        managed_rules: typing.Optional[typing.Sequence[typing.Union["ManagedRule", typing.Dict[str, typing.Any]]]] = None,
+        cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[builtins.str, typing.Any]]] = None,
+        managed_rules: typing.Optional[typing.Sequence[typing.Union["ManagedRule", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''(experimental) Properties to configure the web acl.
 
@@ -145,16 +139,10 @@ class CloudFrontWebAclProps:
         if isinstance(cidr_allow_list, dict):
             cidr_allow_list = CidrAllowList(**cidr_allow_list)
         if __debug__:
-            def stub(
-                *,
-                cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[str, typing.Any]]] = None,
-                managed_rules: typing.Optional[typing.Sequence[typing.Union[ManagedRule, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ef5772598b3c7d231378f10846d94f00acdb7a6a00c290902b0f3d6fb2917a2a)
             check_type(argname="argument cidr_allow_list", value=cidr_allow_list, expected_type=type_hints["cidr_allow_list"])
             check_type(argname="argument managed_rules", value=managed_rules, expected_type=type_hints["managed_rules"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if cidr_allow_list is not None:
             self._values["cidr_allow_list"] = cidr_allow_list
         if managed_rules is not None:
@@ -195,7 +183,7 @@ class CloudFrontWebAclProps:
 
 
 class CloudfrontWebAcl(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-prototyping-sdk/static-website.CloudfrontWebAcl",
 ):
@@ -206,11 +194,11 @@ class CloudfrontWebAcl(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[str, typing.Any]]] = None,
-        managed_rules: typing.Optional[typing.Sequence[typing.Union["ManagedRule", typing.Dict[str, typing.Any]]]] = None,
+        cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[builtins.str, typing.Any]]] = None,
+        managed_rules: typing.Optional[typing.Sequence[typing.Union["ManagedRule", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -221,15 +209,7 @@ class CloudfrontWebAcl(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[str, typing.Any]]] = None,
-                managed_rules: typing.Optional[typing.Sequence[typing.Union[ManagedRule, typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__bda7210fc0eeabc7cb6886da0c5813d2d87516e184bb00f6c26a30a1603b2e01)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontWebAclProps(
@@ -270,12 +250,10 @@ class ManagedRule:
         :stability: experimental
         '''
         if __debug__:
-            def stub(*, name: builtins.str, vendor: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fdd742c7cda95301b9d5bfd45ee16073ed1afed5d3d8dd45ade23d4ea343e9b8)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument vendor", value=vendor, expected_type=type_hints["vendor"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "vendor": vendor,
         }
@@ -343,16 +321,10 @@ class RuntimeOptions:
             new StaticWebsite(scope, 'StaticWebsite', {websiteContentPath: 'path/to/website', runtimeConfig});
         '''
         if __debug__:
-            def stub(
-                *,
-                json_payload: typing.Any,
-                json_file_name: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3ad60143626012a4b255fa575178b1ba2bbe7a959037c2520d6cd003f7ee3cde)
             check_type(argname="argument json_payload", value=json_payload, expected_type=type_hints["json_payload"])
             check_type(argname="argument json_file_name", value=json_file_name, expected_type=type_hints["json_file_name"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "json_payload": json_payload,
         }
         if json_file_name is not None:
@@ -401,7 +373,7 @@ class RuntimeOptions:
 
 
 class StaticWebsite(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-prototyping-sdk/static-website.StaticWebsite",
 ):
@@ -416,16 +388,16 @@ class StaticWebsite(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         website_content_path: builtins.str,
-        default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
-        default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        distribution_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.DistributionProps, typing.Dict[str, typing.Any]]] = None,
-        runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[str, typing.Any]]] = None,
-        web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[str, typing.Any]]] = None,
-        website_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+        default_website_bucket_encryption: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption] = None,
+        default_website_bucket_encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        distribution_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.DistributionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        website_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
     ) -> None:
         '''
         :param scope: -
@@ -441,20 +413,7 @@ class StaticWebsite(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                website_content_path: builtins.str,
-                default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
-                default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                distribution_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.DistributionProps, typing.Dict[str, typing.Any]]] = None,
-                runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[str, typing.Any]]] = None,
-                web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[str, typing.Any]]] = None,
-                website_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__928ab420af56897a7ec742ca8c51b67d3585108c8122ca2cabcbb563ad0078dc)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = StaticWebsiteProps(
@@ -471,30 +430,30 @@ class StaticWebsite(
 
     @builtins.property
     @jsii.member(jsii_name="bucketDeployment")
-    def bucket_deployment(self) -> aws_cdk.aws_s3_deployment.BucketDeployment:
+    def bucket_deployment(self) -> _aws_cdk_aws_s3_deployment_ceddda9d.BucketDeployment:
         '''
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_s3_deployment.BucketDeployment, jsii.get(self, "bucketDeployment"))
+        return typing.cast(_aws_cdk_aws_s3_deployment_ceddda9d.BucketDeployment, jsii.get(self, "bucketDeployment"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudFrontDistribution")
-    def cloud_front_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
+    def cloud_front_distribution(self) -> _aws_cdk_aws_cloudfront_ceddda9d.Distribution:
         '''
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_cloudfront.Distribution, jsii.get(self, "cloudFrontDistribution"))
+        return typing.cast(_aws_cdk_aws_cloudfront_ceddda9d.Distribution, jsii.get(self, "cloudFrontDistribution"))
 
     @builtins.property
     @jsii.member(jsii_name="websiteBucket")
-    def website_bucket(self) -> aws_cdk.aws_s3.IBucket:
+    def website_bucket(self) -> _aws_cdk_aws_s3_ceddda9d.IBucket:
         '''
         :stability: experimental
         '''
-        return typing.cast(aws_cdk.aws_s3.IBucket, jsii.get(self, "websiteBucket"))
+        return typing.cast(_aws_cdk_aws_s3_ceddda9d.IBucket, jsii.get(self, "websiteBucket"))
 
 
-@jsii.implements(aws_cdk.aws_cloudfront.IOrigin)
+@jsii.implements(_aws_cdk_aws_cloudfront_ceddda9d.IOrigin)
 class StaticWebsiteOrigin(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-prototyping-sdk/static-website.StaticWebsiteOrigin",
@@ -513,10 +472,10 @@ class StaticWebsiteOrigin(
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        _scope: constructs.Construct,
+        _scope: _constructs_77d1e7e8.Construct,
         *,
         origin_id: builtins.str,
-    ) -> aws_cdk.aws_cloudfront.OriginBindConfig:
+    ) -> _aws_cdk_aws_cloudfront_ceddda9d.OriginBindConfig:
         '''(experimental) The method called when a given Origin is added (for the first time) to a Distribution.
 
         :param _scope: -
@@ -525,13 +484,13 @@ class StaticWebsiteOrigin(
         :stability: experimental
         '''
         if __debug__:
-            def stub(_scope: constructs.Construct, *, origin_id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__517101de23606077d92f012a8febe5855c5958495ee337733884797c5511261b)
             check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
-        _options = aws_cdk.aws_cloudfront.OriginBindOptions(origin_id=origin_id)
+        _options = _aws_cdk_aws_cloudfront_ceddda9d.OriginBindOptions(
+            origin_id=origin_id
+        )
 
-        return typing.cast(aws_cdk.aws_cloudfront.OriginBindConfig, jsii.invoke(self, "bind", [_scope, _options]))
+        return typing.cast(_aws_cdk_aws_cloudfront_ceddda9d.OriginBindConfig, jsii.invoke(self, "bind", [_scope, _options]))
 
 
 @jsii.data_type(
@@ -552,12 +511,12 @@ class StaticWebsiteProps:
         self,
         *,
         website_content_path: builtins.str,
-        default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
-        default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        distribution_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.DistributionProps, typing.Dict[str, typing.Any]]] = None,
-        runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[str, typing.Any]]] = None,
-        web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[str, typing.Any]]] = None,
-        website_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+        default_website_bucket_encryption: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption] = None,
+        default_website_bucket_encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        distribution_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.DistributionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+        web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        website_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
     ) -> None:
         '''(experimental) Properties for configuring the StaticWebsite.
 
@@ -572,24 +531,13 @@ class StaticWebsiteProps:
         :stability: experimental
         '''
         if isinstance(distribution_props, dict):
-            distribution_props = aws_cdk.aws_cloudfront.DistributionProps(**distribution_props)
+            distribution_props = _aws_cdk_aws_cloudfront_ceddda9d.DistributionProps(**distribution_props)
         if isinstance(runtime_options, dict):
             runtime_options = RuntimeOptions(**runtime_options)
         if isinstance(web_acl_props, dict):
             web_acl_props = CloudFrontWebAclProps(**web_acl_props)
         if __debug__:
-            def stub(
-                *,
-                website_content_path: builtins.str,
-                default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
-                default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                distribution_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.DistributionProps, typing.Dict[str, typing.Any]]] = None,
-                runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[str, typing.Any]]] = None,
-                web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[str, typing.Any]]] = None,
-                website_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__89bfc04e26592eb60007e9b24484c68d1fa7dc22a410a69651d541193f397f08)
             check_type(argname="argument website_content_path", value=website_content_path, expected_type=type_hints["website_content_path"])
             check_type(argname="argument default_website_bucket_encryption", value=default_website_bucket_encryption, expected_type=type_hints["default_website_bucket_encryption"])
             check_type(argname="argument default_website_bucket_encryption_key", value=default_website_bucket_encryption_key, expected_type=type_hints["default_website_bucket_encryption_key"])
@@ -597,7 +545,7 @@ class StaticWebsiteProps:
             check_type(argname="argument runtime_options", value=runtime_options, expected_type=type_hints["runtime_options"])
             check_type(argname="argument web_acl_props", value=web_acl_props, expected_type=type_hints["web_acl_props"])
             check_type(argname="argument website_bucket", value=website_bucket, expected_type=type_hints["website_bucket"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "website_content_path": website_content_path,
         }
         if default_website_bucket_encryption is not None:
@@ -628,7 +576,7 @@ class StaticWebsiteProps:
     @builtins.property
     def default_website_bucket_encryption(
         self,
-    ) -> typing.Optional[aws_cdk.aws_s3.BucketEncryption]:
+    ) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption]:
         '''(experimental) Bucket encryption to use for the default bucket.
 
         Supported options are KMS or S3MANAGED.
@@ -640,12 +588,12 @@ class StaticWebsiteProps:
         :stability: experimental
         '''
         result = self._values.get("default_website_bucket_encryption")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketEncryption], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption], result)
 
     @builtins.property
     def default_website_bucket_encryption_key(
         self,
-    ) -> typing.Optional[aws_cdk.aws_kms.Key]:
+    ) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key]:
         '''(experimental) A predefined KMS customer encryption key to use for the default bucket that gets created.
 
         Note: This is only used if the websiteBucket is left undefined, otherwise all settings from the provided websiteBucket will be used.
@@ -653,12 +601,12 @@ class StaticWebsiteProps:
         :stability: experimental
         '''
         result = self._values.get("default_website_bucket_encryption_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key], result)
 
     @builtins.property
     def distribution_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_cloudfront.DistributionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.DistributionProps]:
         '''(experimental) Custom distribution properties.
 
         Note: defaultBehaviour.origin is a required parameter, however it will not be used as this construct will wire it on your behalf.
@@ -667,7 +615,7 @@ class StaticWebsiteProps:
         :stability: experimental
         '''
         result = self._values.get("distribution_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_cloudfront.DistributionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_cloudfront_ceddda9d.DistributionProps], result)
 
     @builtins.property
     def runtime_options(self) -> typing.Optional[RuntimeOptions]:
@@ -692,13 +640,13 @@ class StaticWebsiteProps:
         return typing.cast(typing.Optional[CloudFrontWebAclProps], result)
 
     @builtins.property
-    def website_bucket(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
+    def website_bucket(self) -> typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket]:
         '''(experimental) Predefined bucket to deploy the website into.
 
         :stability: experimental
         '''
         result = self._values.get("website_bucket")
-        return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -724,3 +672,81 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__9be1ae061cd271ea75f6ed9932a2ad208594eb9b8cae56fd44d609778e3aa1fc(
+    *,
+    cidr_ranges: typing.Sequence[builtins.str],
+    cidr_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ef5772598b3c7d231378f10846d94f00acdb7a6a00c290902b0f3d6fb2917a2a(
+    *,
+    cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[builtins.str, typing.Any]]] = None,
+    managed_rules: typing.Optional[typing.Sequence[typing.Union[ManagedRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bda7210fc0eeabc7cb6886da0c5813d2d87516e184bb00f6c26a30a1603b2e01(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[builtins.str, typing.Any]]] = None,
+    managed_rules: typing.Optional[typing.Sequence[typing.Union[ManagedRule, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fdd742c7cda95301b9d5bfd45ee16073ed1afed5d3d8dd45ade23d4ea343e9b8(
+    *,
+    name: builtins.str,
+    vendor: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3ad60143626012a4b255fa575178b1ba2bbe7a959037c2520d6cd003f7ee3cde(
+    *,
+    json_payload: typing.Any,
+    json_file_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__928ab420af56897a7ec742ca8c51b67d3585108c8122ca2cabcbb563ad0078dc(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    website_content_path: builtins.str,
+    default_website_bucket_encryption: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption] = None,
+    default_website_bucket_encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    distribution_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.DistributionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    website_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__517101de23606077d92f012a8febe5855c5958495ee337733884797c5511261b(
+    _scope: _constructs_77d1e7e8.Construct,
+    *,
+    origin_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__89bfc04e26592eb60007e9b24484c68d1fa7dc22a410a69651d541193f397f08(
+    *,
+    website_content_path: builtins.str,
+    default_website_bucket_encryption: typing.Optional[_aws_cdk_aws_s3_ceddda9d.BucketEncryption] = None,
+    default_website_bucket_encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    distribution_props: typing.Optional[typing.Union[_aws_cdk_aws_cloudfront_ceddda9d.DistributionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[builtins.str, typing.Any]]] = None,
+    web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    website_bucket: typing.Optional[_aws_cdk_aws_s3_ceddda9d.IBucket] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
